unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
* [PATCH] enable debug symbols
@ 2017-02-09 19:04 David Craven
  2017-02-09 19:04 ` [PATCH 1/5] gnu: Use 'license:' prefix in (gnu packages grub) David Craven
                   ` (7 more replies)
  0 siblings, 8 replies; 22+ messages in thread
From: David Craven @ 2017-02-09 19:04 UTC (permalink / raw)
  To: guix-devel

---
 gnu/packages/base.scm   | 1 +
 gnu/packages/glib.scm   | 3 ++-
 gnu/packages/gnome.scm  | 1 +
 gnu/packages/gtk.scm    | 2 +-
 gnu/packages/webkit.scm | 3 ++-
 5 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index c75e03828..b50dd57cc 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -67,6 +67,7 @@
                (base32
                 "0ssi1wpaf7plaswqqjwigppsg5fyh99vdlb9kzl7c9lng89ndq1i"))))
     (build-system gnu-build-system)
+    (outputs '("out" "debug"))
     (synopsis "Hello, GNU world: An example GNU package")
     (description
      "GNU Hello prints the message \"Hello, world!\" and then exits.  It
diff --git a/gnu/packages/glib.scm b/gnu/packages/glib.scm
index 83afa38ae..554ca60d0 100644
--- a/gnu/packages/glib.scm
+++ b/gnu/packages/glib.scm
@@ -150,7 +150,8 @@ shared NFS home directories.")
    (build-system gnu-build-system)
    (outputs '("out"           ; everything
               "bin"           ; glib-mkenums, gtester, etc.; depends on Python
-              "doc"))         ; 20 MiB of GTK-Doc reference
+              "doc"           ; 20 MiB of GTK-Doc reference
+              "debug"))
    (propagated-inputs
     `(("pcre" ,pcre))) ; in the Requires.private field of glib-2.0.pc
    (inputs
diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 955ac610a..5e798713c 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -3693,6 +3693,7 @@ work and the interface is well tested.")
               (sha256
                (base32
                 "0skdsma9rmq01703andigmpbdn2rl34y3lqny19a93v1ph3jb9qk"))))
+    (outputs '("out" "debug"))
     (build-system glib-or-gtk-build-system)
     (arguments
      ;; FIXME: tests run under Xvfb, but fail with:
diff --git a/gnu/packages/gtk.scm b/gnu/packages/gtk.scm
index 0a291370e..f3b001cef 100644
--- a/gnu/packages/gtk.scm
+++ b/gnu/packages/gtk.scm
@@ -661,7 +661,7 @@ application suites.")
               "0bqpx8825b1fdjmz14wq20zq58gq1yi1p5xjps8l6zqid8hmm9zb"))
             (patches (search-patches "gtk3-respect-GUIX_GTK3_PATH.patch"
                                      "gtk3-respect-GUIX_GTK3_IM_MODULE_FILE.patch"))))
-   (outputs '("out" "bin" "doc"))
+   (outputs '("out" "bin" "doc" "debug"))
    (propagated-inputs
     `(("at-spi2-atk" ,at-spi2-atk)
       ("atk" ,atk)
diff --git a/gnu/packages/webkit.scm b/gnu/packages/webkit.scm
index 474232236..a41b5c404 100644
--- a/gnu/packages/webkit.scm
+++ b/gnu/packages/webkit.scm
@@ -61,10 +61,11 @@
               (sha256
                (base32
                 "0v0hkvggxi38cdb3v672qwr0m0y3x2rmnwh8j3q28869li8d9shb"))))
+    (outputs '("out" "debug"))
     (build-system cmake-build-system)
     (arguments
      '(#:tests? #f ; no tests
        #:build-type "Release" ; turn off debugging symbols to save space
        #:configure-flags (list
                           "-DPORT=GTK"
                           (string-append ; uses lib64 by default
@@ -61,10 +61,11 @@
     (arguments
      '(#:tests? #f ; no tests
-       #:build-type "Release" ; turn off debugging symbols to save space
+       #:build-type "Debug" ; turn off debugging symbols to save space
        #:configure-flags (list
                           "-DPORT=GTK"
-- 
2.11.0

^ permalink raw reply related	[flat|nested] 22+ messages in thread

end of thread, other threads:[~2017-02-10 14:24 UTC | newest]

Thread overview: 22+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2017-02-09 19:04 [PATCH] enable debug symbols David Craven
2017-02-09 19:04 ` [PATCH 1/5] gnu: Use 'license:' prefix in (gnu packages grub) David Craven
2017-02-09 23:45   ` Marius Bakke
2017-02-09 19:04 ` [PATCH] update epiphany David Craven
2017-02-10  0:31   ` Mark H Weaver
2017-02-09 19:04 ` [PATCH] update libdrm David Craven
2017-02-09 19:12   ` Marius Bakke
2017-02-09 19:32     ` David Craven
2017-02-10  0:32   ` Mark H Weaver
2017-02-10 12:29     ` David Craven
2017-02-09 19:04 ` [PATCH 2/5] gnu: Add seabios David Craven
2017-02-09 23:55   ` Marius Bakke
2017-02-09 19:04 ` [PATCH 3/5] gnu: Add ovmf David Craven
2017-02-10  0:15   ` Marius Bakke
2017-02-10 13:18     ` David Craven
2017-02-09 19:04 ` [PATCH 4/5] gnu: Add syslinux David Craven
2017-02-10  1:18   ` Marius Bakke
2017-02-10 14:24     ` David Craven
2017-02-09 19:04 ` [PATCH 5/5] gnu: Move (gnu packages grub) and (gnu packages u-boot) ... to (gnu packages bootloaders) David Craven
2017-02-09 19:07 ` [PATCH] enable debug symbols David Craven
2017-02-09 19:23   ` Marius Bakke
2017-02-09 19:29     ` David Craven

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).